@@ -10,6 +10,7 @@ test_that("Output class is same as input class", {
 
 test_that("Data frames are correct size", {
   skip_on_cran()
+  skip_on_ci()
   df <- qualtrics_text %>%
     mark_duplicates(quiet = TRUE) %>%
     mark_duration(min_duration = 100, quiet = TRUE) %>%
@@ -20,10 +21,13 @@ test_that("Data frames are correct size", {
     mark_resolution(quiet = TRUE)
   withr::local_options(lifecycle_verbosity = "quiet")
   expect_true(ncol(collapse_exclusions(df)) == 17)
-  expect_true(ncol(collapse_exclusions(df,
-    exclusion_types =
-      c("duplicates", "duration", "ip")
-  )) == 21)
+  expect_true(
+    ncol(collapse_exclusions(
+      df,
+      exclusion_types = c("duplicates", "duration", "ip")
+    )) ==
+      21
+  )
 })
 
 test_that("Error displayed when exclusion columns not present", {
