@@ -15,7 +15,8 @@ test_that("Column names are renamed correctly", {
     "StartDate"))
   suppressMessages(expect_message(mark_duration(qualtrics_numeric)))
   suppressMessages(expect_no_error(names(mark_duration(qualtrics_fetch2,
-    id_col = "Response ID"))))
+    id_col = "Response ID"
+  ))))
 })
 
 test_that("Output class is same as input class", {
