@@ -14,7 +14,8 @@ test_that("Column names are renamed correctly", {
   )))
   suppressMessages(expect_message(mark_resolution(qualtrics_numeric)))
   suppressMessages(expect_no_error(names(mark_resolution(qualtrics_fetch2,
-    id_col = "Response ID"))))
+    id_col = "Response ID"
+  ))))
 })
 
 test_that("Mark output class is same as input class", {
